Config

Struct Config 

pub struct Config { /* private fields */ }
Configuration parameters for connecting to a Grafana Loki instance.

This struct follows the Builder Pattern, allowing you to specify metadata (labels) that will be attached to every log stream sent to Loki.

Only available when the loki feature is enabled.

Example

let config = LokiConfig::new("[https://logs-prod-us-central1.grafana.net/loki/api/v1/push](https://logs-prod-us-central1.grafana.net/loki/api/v1/push)")
    .job("api-server")
    .app("billing-v2")
    .env("prod")
    .basic_auth(BasicAuth::some("12345", Some("your-api-key")))
    .worker_count(4);

let logger = LokiLogger::new(config);
let logger = Logger::new(logger);

Implementations

Source

impl Config

A network-based logging backend that pushes logs to Grafana Loki.

LokiService transforms internal Message objects into Loki’s JSON “Push” format. It uses a blocking HTTP client, which is intended to be executed within a dedicated background worker thread to avoid blocking the main application.

Stream Labels

Every log sent via this service is tagged with the following labels:

  • job: The logical group (e.g., “logger-service”).
  • app: The specific application name.
  • env: The deployment environment (e.g., “production”, “dev”).
  • level: The severity of the log (automatically extracted from the message).
Client Data
  • url: Base url for loki
  • connection_timeout: Connection timeout (how much time to wait for the connection to happen)
  • request_timeout: Request timeout (how much time to wait for the request’s response)
Logger data:
  • max_retries: Maximum number of retries (only used in the LoggerFactory)
  • worker_count: Number of workers to use (only used in the LoggerFactory)
pub fn new<S>(url: S) -> Self
where S: Into<String>,

Creates a new LokiConfig with default settings.

Parameters
  • url: Base url for loki.
Default Values:
pub fn with_labels<S1, S2, S3, S4>(url: S1, app: S3, job: S2, env: S4) -> Self
where S1: Into<String>, S2: Into<String>, S3: Into<String>, S4: Into<String>,

Creates a new LokiConfig with customized labels default settings.

Parameters
  • url: Base url for loki.
  • job: The logical group (e.g., “logger-service”).
  • app: The specific application name.
  • env: The deployment environment (e.g., “production”, “dev”).
  • level: The severity of the log (automatically extracted from the message).
Default Values:
pub fn get_url(&self) -> &str

Returns the destination Loki base URL.

pub fn get_app(&self) -> &str

Returns the value of the app label.

pub fn get_job(&self) -> &str

Returns the value of the job label.

pub fn get_env(&self) -> &str

Returns the value of the env label.

pub fn get_basic_auth(&self) -> Option<&BasicAuth>

Returns the Basic Authentication credentials if configured.

pub fn get_bearer_auth(&self) -> Option<&str>

Returns the Bearer Token if configured.

pub fn get_connection_timeout(&self) -> Duration

Returns the connection timeout duration.

pub fn get_request_timeout(&self) -> Duration

Returns the request timeout duration.

pub fn get_worker_count(&self) -> usize

Returns the number of background worker threads requested for this service.

pub fn get_max_retries(&self) -> usize

Returns the maximum number of teries allowed for this service.

pub fn url<S: Into<String>>(self, url: S) -> Self

Sets the destination Loki base URL (e.g., http://localhost:3100).

pub fn app<S: Into<String>>(self, app: S) -> Self

Sets the app label to identify this specific application instance.

pub fn job<S: Into<String>>(self, job: S) -> Self

Sets the job label used by Loki for indexing.

pub fn env<S: Into<String>>(self, env: S) -> Self

Sets the env label used by Loki for indexing.

pub fn worker_count(self, worker_count: usize) -> Self

Configures the number of parallel workers that should process logs for this service.

pub fn max_retries(self, max_retries: usize) -> Self

Configures the number of maximum retries that the process should be attempted.

pub fn basic_auth<BA>(self, basic_auth: Option<BA>) -> Self
where BA: Into<BasicAuth>,

Enables Basic Authentication for the Loki connection.

Arguments
  • basic_auth Basic auth object representing the login credentials.
pub fn bearer_auth<S>(self, token: Option<S>) -> Self
where S: Into<String>,

Enables Bearer Token authentication (e.g., JWT).

pub fn connection_timeout<D: Into<Duration>>( self, connection_timeout: D, ) -> Self

Sets the connection timeout to try to log in loki.

pub fn request_timeout<S: Into<Duration>>(self, request_timeout: S) -> Self

Sets the request timeout to try to log in loki.